aboutsummaryrefslogtreecommitdiffstats
path: root/skate/schema.go
diff options
context:
space:
mode:
Diffstat (limited to 'skate/schema.go')
-rw-r--r--skate/schema.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/skate/schema.go b/skate/schema.go
index 50f52d6..f36815f 100644
--- a/skate/schema.go
+++ b/skate/schema.go
@@ -481,12 +481,12 @@ type CSLDate struct {
// family element. Institutional names may be delivered in the same way, but it
// is preferred to set them instead as a literal element.
//
// We include Name, for holding unparsed name, which is not a literal.
type CSLAuthor struct {
Family string `json:"family,omitempty"`
Given string `json:"given,omitempty"`
Literal string `json:"literal,omitempty"`
- Name string `json:"name,omitempty"`
+ RawName string `json:"raw_name,omitempty"`
}
func (b *BiblioRef) Reset() {
@@ -481,12 +481,12 @@ type CSLDate struct {
// is preferred to set them instead as a literal element.
//
-// We include Name, for holding unparsed name, which is not a literal.
+// We include RawName, for holding unparsed name, which is not a literal.
type CSLAuthor struct {
Family string `json:"family,omitempty"`